==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QTranslator_shell.h <==
#ifndef QTRANSLATOR_SHELL_H
#define QTRANSLATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qtranslator.h>
#include <QtJambi/QtJambiAPI>
#include <QTextCodec>
#include <QtCore/QList>
#include <QtCore/QSharedPointer>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/CoreAPI>
#include <memory>
#include <QtJambi/RegistryAPI>


class QTranslator_shell : public QTranslator, public QtJambiShellInterface
{
public:
    QTranslator_shell(QObject* parent0 = nullptr);
    ~QTranslator_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isEmpty() const override;
    void timerEvent(QTimerEvent* event0) override;
    QString translate(const char* context0, const char* sourceText1, const char* disambiguation2, int n3) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTranslator_access : public QTranslator
{
    jboolean __qt_isEmpty_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_translate_const_char_ptr_const_char_ptr_const_char_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring context0, jstring sourceText1, jstring disambiguation2, jint n3) const;
};

#endif // QTRANSLATOR_SHELL_H

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QTranslator_shell.h <==
#ifndef QTRANSLATOR_SHELL_H
#define QTRANSLATOR_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qtranslator.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QSharedPointer>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/CoreAPI>
#include <memory>
#include <QtJambi/RegistryAPI>


class QTranslator_shell : public QTranslator, public QtJambiShellInterface
{
public:
    QTranslator_shell(QObject* parent0 = nullptr);
    ~QTranslator_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QTranslator_mshell;
    friend class QTranslator_oshell;
};


class QTranslator_mshell : public QTranslator_shell
{
public:
    using QTranslator_shell::QTranslator_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QTranslator_oshell : public QTranslator_mshell
{
public:
    using QTranslator_mshell::QTranslator_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isEmpty() const override;
    void timerEvent(QTimerEvent* event0) override;
    QString translate(const char* context0, const char* sourceText1, const char* disambiguation2, int n3) const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTranslator_access : public QTranslator
{
    jboolean __qt_isEmpty_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_translate_const_char_ptr_const_char_ptr_const_char_ptr_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring context0, jstring sourceText1, jstring disambiguation2, jint n3) const;
};

#endif // QTRANSLATOR_SHELL_H
